@@ -3,6 +3,6 @@ import Foundation
 public extension String {
 
     var quoted: String {
-        return "\"\(self)\""
+        "\"\(self)\""
     }
 }
